@@ -512,18 +512,20 @@ class AlgorithmContext:
 
     def create_limit_buy_order(
             self,
-            identifier: str,
             symbol: str,
             price: float,
             amount: float,
-            execute=False
+            execute=False,
+            identifier: str = None,
+            validate_pair=True
     ):
         portfolio_manager = self.get_portfolio_manager(identifier)
         order = portfolio_manager.create_order(
             symbol=symbol,
             price=price,
             amount_target_symbol=amount,
-            order_type=OrderType.LIMIT.value
+            order_type=OrderType.LIMIT.value,
+            validate_pair=validate_pair
         )
 
         if execute:
@@ -535,7 +537,13 @@ class AlgorithmContext:
         return order
 
     def create_limit_sell_order(
-            self, identifier, symbol, price, amount, execute=False
+            self,
+            symbol,
+            price,
+            amount,
+            execute=False,
+            identifier: str = None,
+            validate_pair=True
     ):
         portfolio_manager = self.get_portfolio_manager(identifier)
         order = portfolio_manager.create_order(
@@ -543,7 +551,8 @@ class AlgorithmContext:
             price=price,
             amount_target_symbol=amount,
             order_type=OrderType.LIMIT.value,
-            order_side=OrderSide.SELL.value
+            order_side=OrderSide.SELL.value,
+            validate_pair=validate_pair
         )
 
         if execute:
@@ -558,15 +567,17 @@ class AlgorithmContext:
         self,
         symbol,
         amount_target_symbol,
+        execute=False,
         identifier: str = None,
-        execute=False
+        validate_pair=True
     ):
         portfolio_manager = self.get_portfolio_manager(identifier)
         order = portfolio_manager.create_order(
             symbol=symbol,
             amount_target_symbol=amount_target_symbol,
             order_type=OrderType.MARKET.value,
-            order_side=OrderSide.SELL.value
+            order_side=OrderSide.SELL.value,
+            validate_pair=validate_pair
         )
 
         if execute:
