@@ -49,7 +49,6 @@ class Position(db.Model, ModelExtension):
     )
 
     amount = db.Column(db.Float)
-    cost = db.Column(db.Float)
 
     # Relationships
     portfolio_id = db.Column(db.Integer, db.ForeignKey('portfolios.id'))
@@ -57,13 +56,14 @@ class Position(db.Model, ModelExtension):
 
     # Constraints
     __table_args__ = (
-        UniqueConstraint('symbol', 'portfolio_id', name='_symbol_portfolio_uc'),
+        UniqueConstraint(
+            'symbol', 'portfolio_id', name='_symbol_portfolio_uc'
+        ),
     )
 
     def __init__(self, symbol):
         self.symbol = symbol
         self.amount = 0
-        self.cost = 0
 
     @validates('id', 'symbol')
     def _write_once(self, key, value):
@@ -91,22 +91,3 @@ class Position(db.Model, ModelExtension):
             symbol=self.symbol,
             amount=self.amount,
         )
-
-
-@event.listens_for(Position.orders, 'append')
-def parent_child_relation_inserted(position, order, target):
-
-    if OrderSide.BUY.equals(order.order_side):
-
-        # Check if order id reference not already exists (order split)
-        # If it exists, this would mean that the order is a split order
-        # and therefore it is not needed to update the portfolio or position
-        if order.order_reference and position.orders\
-                .filter_by(
-                    order_reference=order.order_reference
-                ).first() is not None:
-
-            return
-
-        if not OrderType.MARKET.equals(order.order_type):
-            position.portfolio.unallocated -= (order.amount * order.price)
