@@ -1,7 +1,9 @@
 from investing_algorithm_framework.schemas.order import OrderSerializer
 from investing_algorithm_framework.schemas.position import PositionSerializer
+from investing_algorithm_framework.schemas.portfolio import PortfolioSerializer
 
 __all__ = [
     "OrderSerializer",
-    "PositionSerializer"
+    "PositionSerializer",
+    "PortfolioSerializer"
 ]
